==> zk-components-0.0.4.tgz: package/src/components/layout/side-bar/Menu.jsx <==
// 渲染菜单
const renderMenu = (h, props) => {
  const { item } = props
  if (item && !item.meta.hidden) {
    const bool = item.children && !item.hideChildrenInMenu
    return bool ? renderSubMenu(h, props) : renderMenuItem(h, props)
  }
}
// 渲染父级菜单
const renderSubMenu = (h, props) => {
  const { theme, item } = props
  return (
    <el-submenu index={item.path} popperClass={theme}>
      {renderIconAndTitle(h, item.meta)}
      {!item.hideChildrenInMenu && item.children.map((ci) => renderMenu(h, { ...props, item: ci }))}
    </el-submenu>
  )
}

// 渲染子级菜单
const renderMenuItem = (h, props) => {
  const { item, router } = props
  const meta = Object.assign({}, item.meta)
  const httpReg = /(http|https|ftp):\/\/([\w.]+\/?)\S*/
  const hasRemoteUrl = httpReg.test(item.path)
  if (item.children && item.hideChildrenInMenu) {
    // 把要隐藏子菜单的父菜单的所有子菜单添加hidden属性
    item.children.forEach((cd) => {
      cd.meta = Object.assign(cd.meta || {}, { hidden: true })
    })
  }
  return (
    <el-menu-item
      index={item.path}
      nativeOnClick={() => {
        if (hasRemoteUrl) {
          window.open(item.path)
        } else {
          router.push(item.path)
        }
      }}>
      {meta.icon && <iconpark-icon class='menu-icon' name={meta.icon} />}
      <span slot='title'>{meta.title}</span>
    </el-menu-item>
  )
}
// 渲染标题
const renderIconAndTitle = (h, { icon, title }) => {
  if (icon === undefined || icon === 'none' || icon === null) {
    return <span slot='title'>{title}</span>
  }
  return (
    <div>
      <iconpark-icon class='menu-icon' name={icon} />
      <span slot='title'>{title}</span>
    </div>
  )
}

const ZkMenu = {
  name: 'ZkMenu',
  inject: ['layout'],
  data() {
    return {
      activeIndex: '/',
    }
  },
  created() {
    // 页面首次加载时调用，在render之前更新菜单状态
    this.updateMenu()
    // 监听路由变化更新菜单状态
    this.$watch('$route', () => {
      this.updateMenu()
    })
  },
  methods: {
    // 根据当前路由去匹配菜单选中状态
    updateMenu() {
      const routes = this.$route.matched.concat().filter((route) => !route.meta.hidden)
      const route = routes.pop()
      this.activeIndex = route.path.endsWith('/') ? route.path.substr(0, route.path.length - 1) : route.path
    },
  },
  render(h) {
    const {
      layout: { menus, collapsed, theme },
    } = this
    const menuProps = {
      props: {
        collapse: collapsed,
        defaultActive: this.activeIndex,
        uniqueOpened: false,
        collapseTransition: false, //取消组件自带的过渡效果，否则会和外部组件过渡效果冲突
      },
    }
    const menuItems = menus.map((item) => {
      if (item.meta.hidden) return null
      return renderMenu(h, {
        theme,
        item,
        router: this.$router,
      })
    })

    return (
      <el-menu class='zk-menu' {...menuProps}>
        {menuItems}
      </el-menu>
    )
  },
}

export default ZkMenu

==> zk-components-0.0.5.tgz: package/src/components/layout/side-bar/Menu.jsx <==
// 渲染菜单
const renderMenu = (h, props) => {
  const { item } = props
  if (item && !item.meta.hidden) {
    const bool = item.children && !item.hideChildrenInMenu
    return bool ? renderSubMenu(h, props) : renderMenuItem(h, props)
  }
}
// 渲染父级菜单
const renderSubMenu = (h, props) => {
  const { theme, item } = props
  return (
    <el-submenu index={item.path} popperClass={theme}>
      {renderIconAndTitle(h, item.meta)}
      {!item.hideChildrenInMenu && item.children.map((ci) => renderMenu(h, { ...props, item: ci }))}
    </el-submenu>
  )
}

// 渲染子级菜单
const renderMenuItem = (h, props) => {
  const { item, router } = props
  const meta = Object.assign({}, item.meta)
  const httpReg = /(http|https|ftp):\/\/([\w.]+\/?)\S*/
  const hasRemoteUrl = httpReg.test(item.path)
  if (item.children && item.hideChildrenInMenu) {
    // 把要隐藏子菜单的父菜单的所有子菜单添加hidden属性
    item.children.forEach((cd) => {
      cd.meta = Object.assign(cd.meta || {}, { hidden: true })
    })
  }
  return (
    <el-menu-item
      index={item.path}
      nativeOnClick={() => {
        if (hasRemoteUrl) {
          window.open(item.path)
        } else {
          router.push(item.path)
        }
      }}>
      {meta.icon && <iconpark-icon class='menu-icon' name={meta.icon} />}
      <span slot='title'>{meta.title}</span>
    </el-menu-item>
  )
}
// 渲染标题
const renderIconAndTitle = (h, { icon, title }) => {
  if (icon === undefined || icon === 'none' || icon === null) {
    return <span slot='title'>{title}</span>
  }
  return (
    <div slot='title'>
      <iconpark-icon class='menu-icon' name={icon} />
      <span>{title}</span>
    </div>
  )
}

const ZkMenu = {
  name: 'ZkMenu',
  inject: ['layout'],
  data() {
    return {
      activeIndex: '/',
    }
  },
  created() {
    // 页面首次加载时调用，在render之前更新菜单状态
    this.updateMenu()
    // 监听路由变化更新菜单状态
    this.$watch('$route', () => {
      this.updateMenu()
    })
  },
  methods: {
    // 根据当前路由去匹配菜单选中状态
    updateMenu() {
      const routes = this.$route.matched.concat().filter((route) => !route.meta.hidden)
      const route = routes.pop()
      this.activeIndex = route.path.endsWith('/') ? route.path.substr(0, route.path.length - 1) : route.path
    },
  },
  render(h) {
    const {
      layout: { menus, collapsed, theme },
    } = this
    const menuProps = {
      props: {
        collapse: collapsed,
        defaultActive: this.activeIndex,
        uniqueOpened: false,
        collapseTransition: false, //取消组件自带的过渡效果，否则会和外部组件过渡效果冲突
      },
    }
    const menuItems = menus.map((item) => {
      if (item.meta.hidden) return null
      return renderMenu(h, {
        theme,
        item,
        router: this.$router,
      })
    })

    return (
      <el-menu class='zk-menu' {...menuProps}>
        {menuItems}
      </el-menu>
    )
  },
}

export default ZkMenu
